@@ -84,27 +84,25 @@ begins with a space)."
 		 function)
   :group 'buffers-tab)
 
-(defcustom buffers-tab-selection-function 'select-buffers-tab-buffers-by-mode
-  "*If non-nil, a function specifying the buffers to select from the
+(defvar buffers-tab-selection-function 'select-buffers-tab-buffers-by-mode
+  "*If non-nil, a function specifying the buffers to select in the
 buffers tab.  This is passed two buffers and should return non-nil if
-the second buffer should be selected.  The default value
+the first buffer should be selected.  The default value
 `select-buffers-tab-buffers-by-mode' groups buffers by major mode and
-by `buffers-tab-grouping-regexp'."
+by `buffers-tab-grouping-regexp'.")
 
-  :type '(choice (const :tag "None" nil)
-		 function)
-  :group 'buffers-tab)
+(make-obsolete-variable buffers-tab-selection-function
+			"Set `buffers-tab-filter-functions' instead.")
 
-(defcustom buffers-tab-filter-functions (list buffers-tab-selection-function)
-  "*If non-nil, a list of functions specifying the buffers to select 
-from the buffers tab.
+(defcustom buffers-tab-filter-functions (list 'select-buffers-tab-buffers-by-mode)
+  "*If non-nil, a list of functions specifying the buffers to include
+in the buffers tab, depending on the context.
 Each function in the list is passed two buffers, the buffer to
 potentially select and the context buffer, and should return non-nil
 if the first buffer should be selected.  The default value groups
 buffers by major mode and by `buffers-tab-grouping-regexp'."
 
-  :type '(choice (const :tag "None" nil)
-		 sexp)
+  :type '(repeat function)
   :group 'buffers-tab)
 
 (defcustom buffers-tab-sort-function nil
